@@ -7,8 +7,11 @@ use parent 'WiringPi::API';
 
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '2.36.2';
+our $VERSION = '2.36.3';
 
+sub gpio_layout {
+    return $_[0]->gpio_layout;
+}
 sub pin_to_gpio {
     my ($self, $pin, $scheme) = @_;
 
@@ -22,7 +25,7 @@ sub pin_to_gpio {
     elsif ($scheme == RPI_MODE_PHYS){
         return $self->phys_to_gpio($pin);
     }
-    elsif (($scheme == RPI_MODE_GPIO) || ($scheme == RPI_MODE_GPIO_SYS)){
+    elsif ($scheme == RPI_MODE_GPIO){
         return $pin;
     }
     if ($scheme == RPI_MODE_UNINIT){
@@ -47,7 +50,7 @@ sub pin_map {
         if ($scheme == RPI_MODE_WPI) {
             $pin = $self->phys_to_wpi($_);
         }
-        elsif (($scheme == RPI_MODE_GPIO) || ($scheme == RPI_MODE_GPIO_SYS)){
+        elsif ($scheme == RPI_MODE_GPIO){
             $pin = $self->phys_to_gpio($_);
         }
         elsif ($scheme == RPI_MODE_PHYS){
@@ -70,6 +73,14 @@ sub pin_scheme {
         ? $ENV{RPI_PIN_MODE}
         : RPI_MODE_UNINIT;
 }
+sub pwm_range {
+    my ($self, $range) = @_;
+    if (defined $range){
+       $self->{pwm_range} = $range;
+        $self->pwm_set_range($range);
+    }
+    return defined $self->{pwm_range} ? $self->{pwm_range} : 1023;
+}
 sub export_pin {
     my ($self, $pin) = @_;
     system "sudo", "gpio", "export", $self->pin_to_gpio($pin), "in";
@@ -100,6 +111,7 @@ sub cleanup{
     for (split /,/, $pins){
         `sudo gpio -g mode $_ in`;
         `sudo gpio -g mode $_ tri`;
+        delete $ENV{RPI_PINS};
     }
 }
 sub _vim{1;};
@@ -120,6 +132,10 @@ used independently.
 
 =head1 METHODS
 
+=head2 gpio_layout()
+
+Returns the GPIO layout which indicates the board revision number.
+
 =head2 pin_scheme()
 
 Returns the current pin mapping in use. Returns C<0> for C<wiringPi> scheme,
@@ -131,7 +147,7 @@ If using L<RPi::WiringPi::Constant>, these map out to:
 
     0  => RPI_MODE_WPI
     1  => RPI_MODE_GPIO
-    2  => RPI_MODE_GPIO_SYS
+    2  => RPI_MODE_GPIO_SYS # unused in RPi::WiringPi
     3  => RPI_MODE_PHYS
     -1 => RPI_MODE_UNINIT
 
@@ -207,6 +223,22 @@ Parameters:
 
 Mandatory: The pin number printed on the physical Pi board.
 
+=head2 pwm_range($range)
+
+Changes the range of Pulse Width Modulation (PWM). The default is C<0> through
+C<1023>.
+
+Parameters:
+
+=over 8
+=item   $range
+=back
+
+Mandatory: An integer specifying the high-end of the range. The range always
+starts at C<0>. Eg: if C<$range> is C<359>, if you incremented PWM by C<1>
+every second, you'd rotate a step motor one complete rotation in exactly one
+minute.
+
 =head2 export_pin($pin_num)
 
 Exports a pin. Only needed if using the C<setup_sys()> initialization method.
